# RIT SIS \n

## Package Containing Some Of the Features of SIS

# Functions Available

>dict getAttendance(usn,dob)

This returns the attendance of the student with ResultCode as ** Success ** and ResultCode will be ** Fail ** if the credentials are incorrect.

>bool isStudent(usn,dob)

This returns ** true ** if credentials are correct and ** false ** otherwise

>dict getDetails(usn,dob)

This returns the details of the student